@@ -20,21 +20,21 @@
 
 #include "kgamedialog.h"
 
-#include <QLayout>
 //Added by qt3to4:
-#include <QVBoxLayout>
 #include <QList>
+#include <QPushButton>
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kvbox.h>
-#include <kdebug.h>
+
+#include "kfourinline_debug.h"
 
 #include "kgamedialogconfig.h"
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgame.h>
 
-#include "kgamedialog.moc"
+
 
 class KGameDialogPrivate
 {
@@ -65,23 +65,23 @@ KGameDialog::KGameDialog(KGame* g, KPlayer* owner, const QString& title,
     : KPageDialog(parent),
       d( new KGameDialogPrivate )
 {
-    setCaption(title);
-    setButtons(Ok|Default|Apply|Cancel);
-    setDefaultButton(Ok);
+    setWindowTitle(title);
+    //QT5 setButtons(Ok|Default|Apply|Cancel);
+    //QT5 setDefaultButton(Ok);
     setFaceType(KPageDialog::Tabbed);
     setModal(true);
  init(g, owner);
  addNetworkConfig(new KGameDialogNetworkConfig(0));
- connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
- connect(this,SIGNAL(defaultClicked()),this,SLOT(slotDefault()));
- connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
+ connect(button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &KGameDialog::slotOk);
+ connect(button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KGameDialog::slotDefault);
+ connect(button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &KGameDialog::slotApply);
 }
 
 void KGameDialog::init(KGame* g, KPlayer* owner)
 {
 //AB: do we need a "Cancel" Button? currently removed
 
-// kDebug(11001) << ": this=" << this;
+// qCDebug(KFOURINLINE_LOG) << ": this=" << this;
 
  setOwner(owner);
  setKGame(g);
@@ -94,7 +94,7 @@ void KGameDialog::init(KGame* g, KPlayer* owner)
 
 KGameDialog::~KGameDialog()
 {
-// kDebug(11001) << "DESTRUCT KGameDialog" << this;
+// qCDebug(KFOURINLINE_LOG) << "DESTRUCT KGameDialog" << this;
  qDeleteAll(d->mConfigWidgets);
  delete d;
 }
@@ -116,7 +116,7 @@ KVBox *KGameDialog::configPage()
 KVBox* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& title)
 {
  if (!widget) {
-	kError(11001) << "Cannot add NULL config widget";
+	qCCritical(KFOURINLINE_LOG) << "Cannot add NULL config widget";
 	return 0;
  }
  KVBox* page = new KVBox();
@@ -128,26 +128,26 @@ KVBox* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& titl
 void KGameDialog::addConfigWidget(KGameDialogConfig* widget, QWidget* parent)
 {
  if (!widget) {
-	kError(11001) << "Cannot add NULL config widget";
+	qCCritical(KFOURINLINE_LOG) << "Cannot add NULL config widget";
 	return;
  }
  if (!parent) {
-	kError(11001) << "Cannot reparent to NULL widget";
+	qCCritical(KFOURINLINE_LOG) << "Cannot reparent to NULL widget";
 	return;
  }
-// kDebug(11001) << "reparenting widget";
+// qCDebug(KFOURINLINE_LOG) << "reparenting widget";
  widget->setParent(parent);
  widget->move(QPoint(0,0));
  d->mConfigWidgets.append(widget);
  connect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(slotRemoveConfigWidget(QObject*)));
  if (!d->mGame) {
-	kWarning(11001) << "No game has been set!";
+	qCWarning(KFOURINLINE_LOG) << "No game has been set!";
  } else {
 	widget->setKGame(d->mGame);
 	widget->setAdmin(d->mGame->isAdmin());
  }
  if (!d->mOwner) {
-	kWarning(11001) << "No player has been set!";
+	qCWarning(KFOURINLINE_LOG) << "No player has been set!";
  } else {
 	widget->setOwner(d->mOwner);
  }
@@ -187,7 +187,7 @@ void KGameDialog::setOwner(KPlayer* owner)
 	if (d->mConfigWidgets.at(i)) {
 		d->mConfigWidgets.at(i)->setOwner(d->mOwner);
 	} else {
-		kError(11001) << "NULL widget??";
+		qCCritical(KFOURINLINE_LOG) << "NULL widget??";
 	}
  }
 }
@@ -203,9 +203,8 @@ void KGameDialog::setKGame(KGame* g)
  }
  if (d->mGame) {
 	setAdmin(d->mGame->isAdmin());
-	connect(d->mGame, SIGNAL(destroyed()), this, SLOT(slotUnsetKGame()));
-	connect(d->mGame, SIGNAL(signalAdminStatusChanged(bool)),
-			this, SLOT(setAdmin(bool)));
+	connect(d->mGame, &KGame::destroyed, this, &KGameDialog::slotUnsetKGame);
+	connect(d->mGame, &KGame::signalAdminStatusChanged, this, &KGameDialog::setAdmin);
  }
 }
 
@@ -222,18 +221,18 @@ void KGameDialog::slotUnsetKGame() // called when KGame is destroyed
 void KGameDialog::submitToKGame()
 {
  if (!d->mGame) {
-	kError(11001) << ": no game has been set";
+	qCCritical(KFOURINLINE_LOG) << ": no game has been set";
 	return;
  }
  if (!d->mOwner) {
-	kError(11001) << ": no player has been set";
+	qCCritical(KFOURINLINE_LOG) << ": no player has been set";
 	return;
  }
 
  for (int i = 0; i < d->mConfigWidgets.count(); i++) {
-// kDebug(11001) << "submit to kgame" << i;
+// qCDebug(KFOURINLINE_LOG) << "submit to kgame" << i;
 	d->mConfigWidgets.at(i)->submitToKGame(d->mGame, d->mOwner);
-// kDebug(11001) << "done: submit to kgame" << i;
+// qCDebug(KFOURINLINE_LOG) << "done: submit to kgame" << i;
  }
 }
 
