@@ -22,7 +22,7 @@
 #include "kwin4player.h"
 
 // KDE includes
-#include <kdebug.h>
+#include "kfourinline_debug.h"
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgamepropertyhandler.h>
@@ -46,8 +46,7 @@ KWin4Player::KWin4Player() : KPlayer()
 
   // Clear all stats (they will be loaded from the config file later on)
   resetStats();
-  connect(this,SIGNAL(signalPropertyChanged(KGamePropertyBase*,KPlayer*)),
-          this,SLOT(slotPlayerPropertyChanged(KGamePropertyBase*,KPlayer*)));
+  connect(this, &KWin4Player::signalPropertyChanged, this, &KWin4Player::slotPlayerPropertyChanged);
 
   mWin.setValue(0);
   mLost.setValue(0);
@@ -58,8 +57,8 @@ KWin4Player::KWin4Player() : KPlayer()
 // Destructor
 KWin4Player::~KWin4Player()
 {
-  kDebug() << "~KPlayer()";
-  kDebug() << "~KPlayer() done";
+  qCDebug(KFOURINLINE_LOG) << "~KPlayer()";
+  qCDebug(KFOURINLINE_LOG) << "~KPlayer() done";
 }
 
 
@@ -162,7 +161,7 @@ void KWin4Player::resetStats(bool all)
   }
 }
 
-#include "kwin4player.moc"
+
 
 
 
